<?php

namespace Drupal\nft_metadata\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\Component\Serialization\Json;
use Drupal\Component\Serialization\SerializationInterface;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Serializer\Serializer;
use Symfony\Component\HttpFoundation\Request;

/**
 * Handler nft_metadata routes.
 */
class MetadataController extends ControllerBase {

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The current Request object.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * The serialization class to use.
   *
   * @var \Drupal\Component\Serialization\SerializationInterface
   */
  protected $serializer;

  /**
   * Constructs a new MetadataController object.
   */
  public function __construct(
    RouteMatchInterface $route_match,
    Request $request,
    Serializer $serializer
  ) {
    $this->routeMatch = $route_match;
    $this->request = $request;
    $this->serializer = $serializer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_route_match'),
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('serializer')
    );
  }

  /**
   * Outputs a cart view for each non-empty cart belonging to the current user.
   *
   * @return array
   *   A render array.
   */
  public function view() {
    // The entity route name is 'entity.{entity_type}.nft-metadata'.
    $parts = explode('.', $this->routeMatch->getRouteName());
    $entity_type = $parts[1];
    $parameters = $this->routeMatch->getParameters();
    $entity = $this->routeMatch->getParameter($entity_type);

    $build = [];
    $cacheable_metadata = new CacheableMetadata();
    $cacheable_metadata->addCacheContexts(['user', 'session']);
    $cacheable_metadata->addCacheableDependency($entity);

    $query = $this->request->query->all();
    $format = $query['_format'] ?? 'json';
    $context = [];
    $values = $this->serializer->normalize($entity, $format, $context);

    // Response to JSON request.
    if (($query['_format'] ?? NULL) == 'json') {
      return new JsonResponse($values);
    }

    $build['metadata'] = [
      '#type' => 'inline_template',
      '#template' => '<div class="metadata"><code>{{ values }}</code></div>',
      '#context' => [
        'values' => Json::encode($values),
      ],
    ];

    $build['#cache'] = [
      'contexts' => $cacheable_metadata->getCacheContexts(),
      'tags' => $cacheable_metadata->getCacheTags(),
      'max-age' => $cacheable_metadata->getCacheMaxAge(),
    ];

    return $build;
  }

}
