// SPDX-License-Identifier: MIT
pragma solidity ^0.8.0;

import "@openzeppelin/contracts/token/ERC721/ERC721.sol";
import "@openzeppelin/contracts/token/ERC721/extensions/ERC721URIStorage.sol";
import "@openzeppelin/contracts/utils/Counters.sol";

/// @dev Example of a smart contract for your NFT.
/// @see https://docs.openzeppelin.com/contracts/4.x/erc721
contract DrupalNFT is ERC721, ERC721URIStorage {
    using Counters for Counters.Counter;
    Counters.Counter private _tokenIds;

    constructor() ERC721("Drupal NFT", "DFT") {}

    function mintEntity(address drupal_user, string memory tokenURI)
        public
        returns (uint256)
    {
        _tokenIds.increment();

        uint256 newItemId = _tokenIds.current();
        _mint(drupal_user, newItemId);
        _setTokenURI(newItemId, tokenURI);

        return newItemId;
    }
}
