<?php

namespace Drupal\nft_mint\Minter;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Executable\ExecutableInterface;
use Drupal\Core\Plugin\PluginWithFormsInterface;
use Drupal\Core\Url;
use Drupal\nft\Utility\Metadata;
use Drupal\nft\Utility\Transaction;

/**
 * Defines the common interface for all Minter classes.
 *
 * @see \Drupal\nft_mint\Minter\MinterManager
 * @see \Drupal\nft_mint\Minter\Annotation\Minter
 * @see plugin_api
 */
interface MinterPluginInterface extends PluginInspectionInterface, PluginWithFormsInterface, ExecutableInterface {

  /**
   * Mint an Entity from normalized Metada values.
   *
   * @param \Drupal\nft\Utility\Metadata
   *   A normalized array of values
   * @param array $context
   *   Extra information.
   *
   * @return \Drupal\nft\Utility\Transaction
   *   A transaction object.
   *
   * @throws \Exception
   */
  public function mint(Metadata $metadata, array $context = []): Transaction;

  /**
   * Generate NFT metadata for a given entity.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   A given entity.
   * @param array $context
   *   Extra information.
   *
   * @return \Drupal\nft\Utility\Metadata
   *   A metadata object.
   */
  public function metadata(EntityInterface $entity, array $context = []): Metadata;

  /**
   * Generate file URL from Metadata values and/or from a given entity.
   *
   * @param \Drupal\nft\Utility\Metadata
   *   A metadata object.
   * @param array $context
   *   Extra information.
   *
   * @return \Drupal\Core\Url
   *   The Url object.
   *
   * @throws \Exception
   */
  public function toUrl(Metadata $metadata, array $context = []): Url;

}
