<?php

namespace Drupal\nft\Plugin\Field\FieldFormatter;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'string_metadata' formatter.
 *
 * @FieldFormatter(
 *   id = "string_metadata",
 *   label = @Translation("Metadata"),
 *   field_types = {
 *     "string_long",
 *   }
 * )
 */
class MetadataFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $rows = [];

      foreach (Json::decode($item->value) as $key => $value) {
        $row = [];
        $row[] = ['data' => ['#markup' => $key]];
        $row[] = ['data' => ['#markup' => $value]];
        $rows[] = $row;
      }

      $elements[$delta] = [
        '#theme' => 'table',
        '#header' => [$this->t('Key'), $this->t('Value')],
        '#rows' => $rows,
        '#empty' => t('Empty.'),
      ];
    }

    return $elements;
  }

}
