<?php

namespace Drupal\nft\Plugin\Field\FieldWidget;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\nft\Utility\Metadata;

/**
 * Plugin implementation of the 'string_metadata' widget.
 *
 * @FieldWidget(
 *   id = "string_metadata",
 *   label = @Translation("Metadata"),
 *   field_types = {
 *     "string_long"
 *   }
 * )
 */
class MetadataWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $metadata = new Metadata();

    $values = Json::decode($items[$delta]->value ?? '');

    $is_minted = FALSE;

    $element['value'] = $element + [
      '#type' => 'details',
      '#title' => $this->t('Metadata'),
      '#open' => TRUE,
      '#attributes' => ['class' => ['js-metadata', 'metadata']],
    ];

    if ($is_minted) {
      $element['#prefix'] = $element['#prefix'] ?? '';
      $element['#prefix'] .= '<div class="messages messages--warning">';
      $element['#prefix'] .= $this->t('NFT has been minted.') . ' ' . $this->t('Its values cannot be edited.');
      $element['#prefix'] .= '</div>';
    }

    foreach ($metadata->getValues() as $key => $value) {
      $element['value'][$key] = [
        '#type' => 'textfield',
        '#title' => $this->t(ucfirst(str_replace('_', ' ', $key))),
        '#default_value' => $values[$key] ?? NULL,
        '#attributes' => ['class' => ['js-metadata-' . $key, 'metadata-' . $key]],
        '#required' => Metadata::isRequired($key),
        '#disabled' => $is_minted,
      ];
    }

    return $element;
  }

  /**
   * {@inheritDoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      $values[$delta] = Json::encode($value['value']);
    }

    return $values;
  }

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    return $field_definition->getName() === 'metadata';
  }

}
