<?php

namespace Drupal\nft\Utility;

/**
 * Representation of a Transaction to a Blockchain in the context of Drupal.
 */
class Transaction {

  /**
   * Details of a transaction.
   *
   * @var array
   */
  protected $values;

  /**
   * Construct a new Transaction object.
   *
   * @param array $values
   *   The details of the transaction.
   */
  public function __construct(array $values = []) {
    $this->values = $values + $this->defaultValues();
  }

  /**
   * Get default values.
   *
   * @return array
   */
  public function defaultValues() {
    return [
      'status' => FALSE,
      'context' => [],
      'user' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * Get values of the transaction.
   *
   * @return array
   */
  public function getValues() {
    return $this->values;
  }

  /**
   * Update values of the transaction.
   *
   * @param array $values
   *   (optional) New value list.
   */
  public function setValues(array $values = []) {
    $this->values = $values;
  }

  /**
   * Set a single value.
   *
   * @param array $key
   * @param array $value
   */
  public function set(string $key, $value = NULL) {
    $this->values[$key] = $value;
  }

  /**
   * Get a single value.
   */
  public function get(string $key) {
    return $this->values[$key] ?? NULL;
  }

}
